@@ -15,11 +15,11 @@
 #' @references \url{https://arxiv.org/pdf/1907.04907.pdf}
 #' @return an object of class ETM which is a torch \code{nn_module} containing o.a.
 #' \itemize{
-#'   \item{num_topics: }{the number of topics}
-#'   \item{vocab: }{character vector with the terminology used in the model}
-#'   \item{vocab_size: }{the number of words in \code{vocab}}
-#'   \item{rho: }{The word embeddings}
-#'   \item{alphas: }{The topic embeddings}
+#'   \item num_topics: the number of topics
+#'   \item vocab: character vector with the terminology used in the model
+#'   \item vocab_size: the number of words in \code{vocab}
+#'   \item rho: The word embeddings
+#'   \item alphas: The topic embeddings
 #' }
 #' @section Methods:
 #' \describe{
@@ -68,7 +68,11 @@
 #' torch_manual_seed(4321)
 #' model       <- ETM(k = 8, dim = 100, embeddings = embeddings, dropout = 0.5)
 #' optimizer   <- optim_adam(params = model$parameters, lr = 0.005, weight_decay = 0.0000012)
-#' overview    <- model$fit(data = dtm, optimizer = optimizer, epoch = 40, batch_size = 1000)
+#' epochs      <- 40
+#' \dontshow{
+#' epochs      <- 5
+#' }
+#' overview    <- model$fit(data = dtm, optimizer = optimizer, epoch = epochs, batch_size = 1000)
 #' scores      <- predict(model, dtm, type = "topics")
 #' 
 #' lastbatch   <- subset(overview$loss, overview$loss$batch_is_last == TRUE)
@@ -86,12 +90,16 @@
 #' torch_manual_seed(4321)
 #' model       <- ETM(k = 8, dim = 100, embeddings = 15, dropout = 0.5, vocab = colnames(dtm))
 #' optimizer   <- optim_adam(params = model$parameters, lr = 0.005, weight_decay = 0.0000012)
-#' overview    <- model$fit(data = dtm, optimizer = optimizer, epoch = 40, batch_size = 1000)
+#' epochs      <- 40
+#' \dontshow{
+#' epochs      <- 5
+#' }
+#' overview    <- model$fit(data = dtm, optimizer = optimizer, epoch = epochs, batch_size = 1000)
 #' terminology <- predict(model, type = "terms", top_n = 7)
 #' terminology
 #' 
 #' 
-#' 
+#' \donttest{
 #' \dontshow{
 #' ##
 #' ## Another example using fit_original
@@ -123,6 +131,7 @@
 #' terminology <- predict(model, type = "terms", top_n = 4)
 #' terminology
 #' }
+#' }
 #' 
 #' }
 ETM <- nn_module(
@@ -395,6 +404,9 @@ ETM <- nn_module(
   fit = function(data, optimizer, epoch, batch_size, normalize = TRUE, clip = 0, lr_anneal_factor = 4, lr_anneal_nonmono = 10){
     stopifnot(inherits(data, "sparseMatrix"))
     data  <- data[Matrix::rowSums(data) > 0, ]
+    if(nrow(data) == 0){
+      stop("data argument (document term matrix) does not contain any documents (which contain words part of the vocabulary)")
+    }
     idx   <- split_train_test(data, train_pct = 0.7)
     test1 <- as_tokencounts(data[idx$test1, ])
     test2 <- as_tokencounts(data[idx$test2, ])
@@ -665,7 +677,7 @@ as.matrix.ETM <- function(x, type = c("embedding", "beta"), which = c("topics",
 #' }
 #' 
 #' \dontshow{if(require(torch) && torch::torch_is_installed() && 
-#'              require(textplot) && require(uwot) && require(ggrepel) && require(ggalt))
+#'              require(textplot) && require(uwot) && require(ggrepel))
 #' \{
 #' }
 #' library(torch)
@@ -673,11 +685,14 @@ as.matrix.ETM <- function(x, type = c("embedding", "beta"), which = c("topics",
 #' library(textplot)
 #' library(uwot)
 #' library(ggrepel)
-#' library(ggalt)
 #' path  <- system.file(package = "topicmodels.etm", "example", "example_etm.ckpt")
 #' model <- torch_load(path)
+#' n_epochs <- NULL
+#' \dontshow{
+#'   n_epochs <- 5
+#' }
 #' plt   <- plot(model, type = "topics", top_n = 7, which = c(1, 2, 14, 16, 18, 19),
-#'               metric = "cosine", n_neighbors = 15, 
+#'               metric = "cosine", n_neighbors = 15, n_epochs = n_epochs,
 #'               fast_sgd = FALSE, n_threads = 2, verbose = TRUE,
 #'               title = "ETM Topics example")
 #' plt
@@ -743,8 +758,12 @@ plot.ETM <- function(x, type = c("loss", "topics"), which, top_n = 4,
 #' library(uwot)
 #' path     <- system.file(package = "topicmodels.etm", "example", "example_etm.ckpt")
 #' model    <- torch_load(path)
+#' n_epochs <- NULL
+#' \dontshow{
+#'   n_epochs <- 5
+#' }
 #' overview <- summary(model, 
-#'                     metric = "cosine", n_neighbors = 15, 
+#'                     metric = "cosine", n_neighbors = 15, n_epochs = n_epochs,
 #'                     fast_sgd = FALSE, n_threads = 1, verbose = TRUE) 
 #' overview$center
 #' overview$embed_2d
